summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2017-08-06 20:00:42 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2017-08-07 09:43:44 -0500
commita862fd04b96cd5a3044a1aa7f3cc099c1618e796 (patch)
treedf949808b830ac66ca88fa27178f62566be5eee4
parent752c6c0042aa1de559139e79be59aa258efa70c1 (diff)
downloadlibpng-a862fd04b96cd5a3044a1aa7f3cc099c1618e796.tar.gz
[libpng15] Imported from libpng-1.5.29beta02.tarv1.5.29beta02
-rw-r--r--LICENSE4
-rw-r--r--README8
-rw-r--r--contrib/gregbook/README2
-rw-r--r--libpngpf.32
-rw-r--r--png.52
-rw-r--r--png.c4
-rw-r--r--png.h10
-rw-r--r--pngconf.h2
-rw-r--r--projects/vstudio/README.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt2
-rw-r--r--scripts/pnglibconf.h.prebuilt2
12 files changed, 21 insertions, 21 deletions
diff --git a/LICENSE b/LICENSE
index 14e590f85..afc64938c 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.0.7, July 1, 2000 through 1.5.29beta02, April 1, 2017 are
+libpng versions 1.0.7, July 1, 2000 through 1.5.29beta02, August 7, 2017 are
Copyright (c) 2000-2002, 2004, 2006-2017 Glenn Randers-Pehrson, are
derived from libpng-1.0.6, and are distributed according to the same
disclaimer and license as libpng-1.0.6 with the following individuals
@@ -126,4 +126,4 @@ any encryption software. See the EAR, paragraphs 734.3(b)(3) and
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-April 1, 2017
+August 7, 2017
diff --git a/README b/README
index ec9bbb41d..f90afad0c 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.29beta02 - April 1, 2017 (shared library 15.0)
+README for libpng version 1.5.29beta02 - August 7, 2017 (shared library 15.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
@@ -88,11 +88,11 @@ zlib should be available at the same place that libpng is, or at zlib.net.
You may also want a copy of the PNG specification. It is available
as an RFC, a W3C Recommendation, and an ISO/IEC Standard. You can find
-these at http://www.libpng.org/pub/png/documents/
+these at http://www.libpng.org/pub/png/pngdocs.html .
This code is currently being archived at libpng.sourceforge.io in the
-[DOWNLOAD] area, and at ftp://ftp.simplesystems.org. If you can't find it
-in any of those places, e-mail me, and I'll help you find it.
+[DOWNLOAD] area, and at ftp://ftp-osl.osuosl.org/pub/libpng/src . If you
+can't find it in any of those places, e-mail me, and I'll help you find it.
I am not a lawyer, but I believe that the Export Control Classification
Number (ECCN) for libpng is EAR99, which means not subject to export
diff --git a/contrib/gregbook/README b/contrib/gregbook/README
index 4d7be4260..90e28f7ce 100644
--- a/contrib/gregbook/README
+++ b/contrib/gregbook/README
@@ -63,7 +63,7 @@ BUILD INSTRUCTIONS
- Prerequisites (in order of compilation):
- - zlib http://zlib.net/
+ - zlib https://zlib.net/
- libpng http://www.libpng.org/pub/png/libpng.html
- pngbook http://www.libpng.org/pub/png/book/sources.html
diff --git a/libpngpf.3 b/libpngpf.3
index 3bb06898e..1ce5e45ca 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "April 1, 2017"
+.TH LIBPNGPF 3 "August 7, 2017"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.5.29beta02
(private functions)
diff --git a/png.5 b/png.5
index b0cbd2cfa..d27fc2c5c 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "April 1, 2017"
+.TH PNG 5 "August 7, 2017"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 8d357901e..a99ee9bec 100644
--- a/png.c
+++ b/png.c
@@ -656,14 +656,14 @@ png_get_copyright(png_const_structp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.5.29beta02 - April 1, 2017" PNG_STRING_NEWLINE \
+ "libpng version 1.5.29beta02 - August 7, 2017" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2002,2004,2006-2017 Glenn Randers-Pehrson" \
PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.5.29beta02 - April 1, 2017\
+ return "libpng version 1.5.29beta02 - August 7, 2017\
Copyright (c) 1998-2002,2004,2006-2017 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 67733153e..e06b0be1c 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.5.29beta02, April 1, 2017
+ * libpng version 1.5.29beta02, August 7, 2017
*
* Copyright (c) 1998-2002,2004,2006-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/projects/vstudio/README.txt b/projects/vstudio/README.txt
index e80ed45b5..8440924b2 100644
--- a/projects/vstudio/README.txt
+++ b/projects/vstudio/README.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.5.29beta02 - April 1, 2017
+libpng version 1.5.29beta02 - August 7, 2017
Copyright (c) 2010,2013,2016 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 7d58a7bba..1bbaec7a9 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.5.29beta02 - April 1, 2017
+ * libpng version 1.5.29beta02 - August 7, 2017
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 187b7e85c..4ed7c4cd1 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
-Makefiles for libpng version 1.5.29beta02 - April 1, 2017
+Makefiles for libpng version 1.5.29beta02 - August 7, 2017
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index b303a9528..1ddcc9142 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -1,7 +1,7 @@
/* 1.5.29beta02 STANDARD API DEFINITION */
/* pnglibconf.h - library build configuration */
-/* libpng version 1.5.29beta02 - April 1, 2017 */
+/* libpng version 1.5.29beta02 - August 7, 2017 */
/* Copyright (c) 2011-2015 Glenn Randers-Pehrson */
diff --git a/png.h b/png.h
index 0f88bd72f..7d421f6da 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.29beta02, April 1, 2017
*
* Copyright (c) 1998-2002,2004,2006-2017 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -12,7 +12,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.29beta02, April 1, 2017:
* Glenn Randers-Pehrson.
* See also "Contributing Authors", below.
*/
@@ -25,7 +25,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.0.7, July 1, 2000 through 1.5.29beta02, April 1, 2017 are
* Copyright (c) 2000-2002, 2004, 2006-2017 Glenn Randers-Pehrson, are
* derived from libpng-1.0.6, and are distributed according to the same
* disclaimer and license as libpng-1.0.6 with the following individuals
@@ -235,7 +235,7 @@
* Y2K compliance in libpng:
* =========================
*
- * April 1, 2017
+ * August 7, 2017
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
@@ -304,7 +304,7 @@
/* Version information for png.h - this should match the version in png.c */
#define PNG_LIBPNG_VER_STRING "1.5.29beta02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.29beta02 - April 1, 2017\n"
+ " libpng version 1.5.29beta02 - August 7, 2017\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.29beta02, April 1, 2017
+ * libpng version 1.5.29beta02, August 7, 2017
*
* Copyright (c) 1998-2002,2004,2006-2017 Glenn Randers-Pehrson
@@ -12,7 +12,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.29beta02, April 1, 2017:
+ * libpng versions 0.97, January 1998, through 1.5.29beta02, August 7, 2017:
* Glenn Randers-Pehrson.
* See also "Contributing Authors", below.
@@ -25,7 +25,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.0.7, July 1, 2000 through 1.5.29beta02, April 1, 2017 are
+ * libpng versions 1.0.7, July 1, 2000 through 1.5.29beta02, August 7, 2017 are
* Copyright (c) 2000-2002, 2004, 2006-2017 Glenn Randers-Pehrson, are
* derived from libpng-1.0.6, and are distributed according to the same